@@ -4,10 +4,13 @@ from strawberry.types import ExecutionContext, Info
 
 
 class Extension:
-    def on_request_start(self, *, execution_context: ExecutionContext):
+    def __init__(self, *, execution_context: ExecutionContext):
+        self.execution_context = execution_context
+
+    def on_request_start(self):
         ...
 
-    def on_request_end(self, *, execution_context: ExecutionContext):
+    def on_request_end(self):
         ...
 
     def on_validation_start(self):
