@@ -1,12 +1,13 @@
 from datetime import date, datetime, time
 from decimal import Decimal
 from typing import NewType, Type
+from uuid import UUID
 
 from .custom_scalar import SCALAR_REGISTRY
 
 
 ID = NewType("ID", str)
-SCALAR_TYPES = [int, str, float, bytes, bool, datetime, date, time, Decimal]
+SCALAR_TYPES = [int, str, float, bytes, bool, UUID, datetime, date, time, Decimal]
 
 
 def is_scalar(annotation: Type) -> bool:
