@@ -1,6 +1,6 @@
 from asyncio import ensure_future
 from inspect import isawaitable
-from typing import Any, Awaitable, Dict, List, Optional, Sequence, Type, cast
+from typing import Any, Awaitable, List, Optional, Sequence, Type, cast
 
 from graphql import (
     ExecutionContext as GraphQLExecutionContext,
@@ -21,24 +21,16 @@ async def execute(
     schema: GraphQLSchema,
     query: str,
     extensions: Sequence[Type[Extension]],
-    root_value: Any = None,
-    context_value: Any = None,
-    variable_values: Dict[str, Any] = None,
+    execution_context: ExecutionContext,
     additional_middlewares: List[Any] = None,
-    operation_name: str = None,
     execution_context_class: Optional[Type[GraphQLExecutionContext]] = None,
     validate_queries: bool = True,
 ) -> ExecutionResult:
-    execution_context = ExecutionContext(
-        query=query,
-        context=context_value,
-        variables=variable_values,
-        operation_name=operation_name,
-    )
-
     extensions_runner = ExtensionsRunner(
         execution_context=execution_context,
-        extensions=[extension() for extension in extensions],
+        extensions=[
+            extension(execution_context=execution_context) for extension in extensions
+        ],
     )
 
     additional_middlewares = additional_middlewares or []
@@ -50,7 +42,9 @@ async def execute(
         try:
             with extensions_runner.parsing():
                 document = parse(query)
+                execution_context.graphql_document = document
         except GraphQLError as error:
+            execution_context.errors = [error]
             return ExecutionResult(
                 data=None,
                 errors=[error],
@@ -60,6 +54,7 @@ async def execute(
         except Exception as error:  # pragma: no cover
             error = GraphQLError(str(error), original_error=error)
 
+            execution_context.errors = [error]
             return ExecutionResult(
                 data=None,
                 errors=[error],
@@ -71,22 +66,25 @@ async def execute(
                 validation_errors = validate(schema, document)
 
             if validation_errors:
+                execution_context.errors = validation_errors
                 return ExecutionResult(data=None, errors=validation_errors)
 
         result = original_execute(
             schema,
             document,
-            root_value=root_value,
+            root_value=execution_context.root_value,
             middleware=extensions_runner.as_middleware_manager(*additional_middlewares),
-            variable_values=variable_values,
-            operation_name=operation_name,
-            context_value=context_value,
+            variable_values=execution_context.variables,
+            operation_name=execution_context.operation_name,
+            context_value=execution_context.context,
             execution_context_class=execution_context_class,
         )
 
         if isawaitable(result):
             result = await cast(Awaitable[GraphQLExecutionResult], result)
 
+        execution_context.result = cast(GraphQLExecutionResult, result)
+
     result = cast(GraphQLExecutionResult, result)
 
     return ExecutionResult(
@@ -100,23 +98,16 @@ def execute_sync(
     schema: GraphQLSchema,
     query: str,
     extensions: Sequence[Type[Extension]],
-    root_value: Any = None,
-    context_value: Any = None,
-    variable_values: Dict[str, Any] = None,
+    execution_context: ExecutionContext,
     additional_middlewares: List[Any] = None,
-    operation_name: str = None,
     execution_context_class: Optional[Type[GraphQLExecutionContext]] = None,
     validate_queries: bool = True,
 ) -> ExecutionResult:
-    execution_context = ExecutionContext(
-        query=query,
-        context=context_value,
-        variables=variable_values,
-        operation_name=operation_name,
-    )
     extensions_runner = ExtensionsRunner(
         execution_context=execution_context,
-        extensions=[extension() for extension in extensions],
+        extensions=[
+            extension(execution_context=execution_context) for extension in extensions
+        ],
     )
 
     additional_middlewares = additional_middlewares or []
@@ -128,7 +119,9 @@ def execute_sync(
         try:
             with extensions_runner.parsing():
                 document = parse(query)
+                execution_context.graphql_document = document
         except GraphQLError as error:
+            execution_context.errors = [error]
             return ExecutionResult(
                 data=None,
                 errors=[error],
@@ -138,6 +131,7 @@ def execute_sync(
         except Exception as error:  # pragma: no cover
             error = GraphQLError(str(error), original_error=error)
 
+            execution_context.errors = [error]
             return ExecutionResult(
                 data=None,
                 errors=[error],
@@ -149,16 +143,17 @@ def execute_sync(
                 validation_errors = validate(schema, document)
 
             if validation_errors:
+                execution_context.errors = validation_errors
                 return ExecutionResult(data=None, errors=validation_errors)
 
         result = original_execute(
             schema,
             document,
-            root_value=root_value,
+            root_value=execution_context.root_value,
             middleware=extensions_runner.as_middleware_manager(*additional_middlewares),
-            variable_values=variable_values,
-            operation_name=operation_name,
-            context_value=context_value,
+            variable_values=execution_context.variables,
+            operation_name=execution_context.operation_name,
+            context_value=execution_context.context,
             execution_context_class=execution_context_class,
         )
 
@@ -166,7 +161,10 @@ def execute_sync(
             ensure_future(cast(Awaitable[GraphQLExecutionResult], result)).cancel()
             raise RuntimeError("GraphQL execution failed to complete synchronously.")
 
-    result = cast(GraphQLExecutionResult, result)
+        result = cast(GraphQLExecutionResult, result)
+        execution_context.result = result
+        if result.errors:
+            execution_context.errors = result.errors
 
     return ExecutionResult(
         data=result.data,
